@@ -24,7 +24,7 @@ def nb_print(*args, sep=' ', end='\n', file=None):
     file_name = sys._getframe(1).f_code.co_filename
     # sys.stdout.write(f'"{__file__}:{sys._getframe().f_lineno}"    {x}\n')
     args = (str(arg) for arg in args)  # REMIND 防止是数字不能被join
-    sys.stdout.write(f'"{file_name}:{line}"  {time.strftime("%H:%M:%S")}  \033[0;30;44m{"".join(args)}\033[0m\n')  # 36  93 96 94
+    sys.stdout.write(f'{time.strftime("%H:%M:%S")}  "{file_name}:{line}"   \033[0;30;44m{"".join(args)}\033[0m\n')  # 36  93 96 94
 
 
 # noinspection PyPep8,PyUnusedLocal
